@@ -1,6 +1,6 @@
 package Business::BalancedPayments;
 {
-  $Business::BalancedPayments::VERSION = '0.0201';
+  $Business::BalancedPayments::VERSION = '0.0500';
 }
 use Moose;
 with 'Business::BalancedPayments::HTTP';
@@ -8,13 +8,20 @@ with 'Business::BalancedPayments::HTTP';
 use Carp qw(croak);
 
 has secret      => (is => 'ro', required => 1                             );
-has merchant    => (is => 'rw', lazy => 1, builder => '_build_merchant'   );
-has marketplace => (is => 'rw', lazy => 1, builder => '_build_marketplace');
+has merchant    => (is => 'ro', lazy => 1, builder => '_build_merchant'   );
+has marketplace => (is => 'ro', lazy => 1, builder => '_build_marketplace');
+has logger      => (is => 'ro');
 
 has api_keys_uri     => (is => 'ro', default => sub { '/v1/api_keys'     });
 has merchants_uri    => (is => 'ro', default => sub { '/v1/merchants'    });
 has marketplaces_uri => (is => 'ro', default => sub { '/v1/marketplaces' });
 
+sub log {
+    my ($self, $level, $msg) = @_;
+    return unless $self->logger;
+    $self->logger->$level($msg);
+}
+
 sub _build_merchant {
     my ($self) = @_;
     my $data = $self->get($self->merchants_uri);
@@ -27,6 +34,11 @@ sub _build_marketplace {
     return $data->{items}[0];
 }
 
+sub get_transactions {
+    my ($self) = @_;
+    return $self->get($self->marketplaces_uri . "/transactions");
+}
+
 sub get_card {
     my ($self, $id) = @_;
     croak 'The id param is missing' unless defined $id;
@@ -129,12 +141,30 @@ sub capture_hold {
         $self->marketplace->{debits_uri}, { hold_uri => $hold->{uri} });
 }
 
+sub get_debit {
+    my ($self, $id) = @_;
+    croak 'The id param is missing' unless defined $id;
+    return $self->get($self->marketplace->{debits_uri} . "/$id");
+}
+
 sub get_hold {
     my ($self, $id) = @_;
     croak 'The id param is missing' unless defined $id;
     return $self->get($self->marketplace->{holds_uri} . "/$id");
 }
 
+sub get_refund {
+    my ($self, $id) = @_;
+    croak 'The id param is missing' unless defined $id;
+    return $self->get($self->marketplace->{refunds_uri} . "/$id");
+}
+
+sub get_refunds {
+    my ($self, $debit) = @_;
+    croak 'The debit param is missing' unless defined $debit;
+    return $self->get($debit->{refunds_uri});
+}
+
 sub void_hold {
     my ($self, $hold) = @_;
     croak 'The hold param must be a hashref' unless ref $hold eq 'HASH';
@@ -202,9 +232,9 @@ sub create_credit {
     if ($bank_account) {
         croak 'The bank_account param must be a hashref'
             unless ref $bank_account eq 'HASH';
-        croak 'The bank_account is a uri' unless$bank_account->{uri};
+        croak 'The bank_account is a uri' unless $bank_account->{uri};
         croak 'The bank_account is missing an credits_uri'
-            unless$bank_account->{account}{credits_uri};
+            unless $bank_account->{account}{credits_uri};
         $credits_uri = $bank_account->{account}{credits_uri};
         $credit->{bank_account_uri} = $bank_account->{uri};
     }
@@ -226,7 +256,7 @@ Business::BalancedPayments - BalancedPayments API bindings
 
 =head1 VERSION
 
-version 0.0201
+version 0.0500
 
 =head1 SYNOPSIS
 
@@ -251,6 +281,46 @@ L<BalancedPayments|https://www.balancedpayments.com> API.
 
 =head1 METHODS
 
+=head2 new
+
+    my $bp = Business::BalancedPayments->new(
+        secret  => $secret,
+        logger  => $logger, # optional
+        retries => 3,       # optional
+    );
+
+Instantiates a new `Business::BalancedPayments` client object.
+Parameters:
+
+=over 4
+
+=item secret
+
+Required. The Balanced Payments secret key for your account.
+
+=item logger
+
+Optional.
+A logger-like object.
+It just needs to have a method named C<DEBUG> that takes a single argument,
+the message to be logged.
+A L<Log::Tiny> object would be a good choice.
+
+=item retries
+
+Optional.
+The number of times to retry requests in cases when Balanced returns a 5xx
+response.
+Defaults to 0.
+
+=back
+
+=head2 get_transactions
+
+    get_transactions()
+
+Returns the transactions for this marketplace.
+
 =head2 get_card
 
     get_card($id)
@@ -366,6 +436,41 @@ and an account hashref, such as one returned by L</get_account>.
 Returns an account hashref.
 See L</get_account> for an example response.
 
+=head2 get_debit
+
+    get_debit($debit_id)
+
+Returns the debit with the given id.
+Example response:
+
+  {
+    id                       =>  "WD1xtdUeixQIfJEsg4RwwHjQ",
+    transaction_number       =>  "W553-201-5667",
+    amount                   =>  50,
+    fee                      =>  1,
+    description              =>  undef,
+    appears_on_statement_as  =>  "example.com",
+    available_at             =>  "2012-10-25T04:48:19.337522Z",
+    created_at               =>  "2012-10-25T04:48:19.443904Z",
+    uri                      =>  "/v1/marketplaces/MK98/debits/WD2L",
+    refunds_uri              => "/v1/marketplaces/MK98/debits/WD2L/refunds",
+    account                  =>  { ...  },
+    hold                     =>  { ...  },
+    meta                     =>  { ...  },
+    source => {
+      brand            => "MasterCard",
+      card_type        => "mastercard",
+      created_at       => "2012-06-07T11:00:40.003671Z",
+      expiration_month => 12,
+      expiration_year  => 2020,
+      id               => "CC92QRQcwUCp5zpzEz7lXKS",
+      is_valid         => 1,
+      last_four        => 5100,
+      name             => undef,
+      uri => "/v1/marketplaces/MK98/accounts/AC7A/cards/CC92QRQcwUCp5zpzEz7lXKS",
+    },
+  }
+
 =head2 get_hold
 
     get_hold($hold_id)
@@ -377,26 +482,15 @@ Example response:
    id          => "HL5byxIzSvf0entZuO9eEsWJ",
    uri         => "/v1/marketplaces/MK98/holds/HL5byxIzSvf0entZuO9eEsWJ",
    amount      => 200,
-   account     => { ... },
-   created_at  => "2012-06-08T09:23:53.745746Z",
-   debit       => undef,
    description => undef,
+   created_at  => "2012-06-08T09:23:53.745746Z",
    expires_at  => "2012-06-15T09:23:53.705009Z",
    fee         => 35,
    is_void     => 0,
-   meta        => {},
-   source => {
-     brand            => "MasterCard",
-     card_type        => "mastercard",
-     created_at       => "2012-06-07T11:00:40.003671Z",
-     expiration_month => 12,
-     expiration_year  => 2020,
-     id               => "CC92QRQcwUCp5zpzEz7lXKS",
-     is_valid         => 1,
-     last_four        => 5100,
-     name             => undef,
-     uri => "/v1/marketplaces/MK98/accounts/AC7A/cards/CC92QRQcwUCp5zpzEz7lXKS",
-   },
+   account     => { ... },
+   debit       => { ... },
+   meta        => { ... },
+   source      => { ... },
  }
 
 =head2 create_hold
@@ -437,6 +531,7 @@ Example response:
 
  {
    id                      => "WD2Lpzyz8Okbhx2Nbw7YuTP3",
+   transaction_number      => "W476-365-3767",
    uri                     => "/v1/marketplaces/MK98/debits/WD2L",
    amount                  => 50,
    appears_on_statement_as => "example.com",
@@ -444,25 +539,74 @@ Example response:
    created_at              => "2012-06-08T09:57:27.750828Z",
    description             => undef,
    fee                     => 1,
-   meta                    => {},
+   meta                    => { ... },
    hold                    => { ... },
    account                 => { ... },
+   source                  => { ... },
    refunds_uri             => "/v1/marketplaces/MK98/debits/WD2L/refunds",
-   source => {
-     brand            => "MasterCard",
-     card_type        => "mastercard",
-     created_at       => "2012-06-07T11:00:40.003671Z",
-     expiration_month => 12,
-     expiration_year  => 2020,
-     id               => "CC92QRQcwUCp5zpzEz7lXKS",
-     is_valid         => 1,
-     last_four        => 5100,
-     name             => undef,
-     uri => "/v1/marketplaces/MK98/accounts/AC7A/cards/CC92QRQcwUCp5zpzEz7lXKS",
-   },
-   transaction_number => "W476-365-3767",
  }
 
+ =head2 get_refund
+
+     get_refund($id)
+
+ Gets a refund by id.
+
+     $bp->get_refund($id);
+
+ Returns a refund hashref.
+ Example response.
+   {
+     id                       =>  'RF74',
+     transaction_number       =>  'RF966-744-5492',
+     amount                   =>  323,
+     fee                      =>  -10,
+     description              =>  '',
+     appears_on_statement_as  =>  'example.com',
+     created_at               =>  '2012-08-27T16:54:46.595330Z',
+     debit                    =>  { ... },
+     meta                     =>  { ... },
+     account                  =>  { ... },
+     uri                      =>  '/v1/marketplaces/MP35/refunds/RF74',
+   }
+
+=head2 get_refunds
+
+    get_refunds($debit)
+
+Gets the refunds associated with a specific debit.
+
+    my $debit = $bp->get_debit($debit_id);
+    $bp->get_refunds($debit);
+
+Returns a refunds hashref.
+Example response.
+  {
+    items => [
+      {
+        id                       =>  'RF74',
+        transaction_number       =>  'RF966-744-5492',
+        amount                   =>  323,
+        fee                      =>  -10,
+        description              =>  '',
+        appears_on_statement_as  =>  'example.com',
+        created_at               =>  '2012-08-27T16:54:46.595330Z',
+        debit                    =>  { ... },
+        meta                     =>  { ... },
+        account                  =>  { ... },
+        uri                      =>  '/v1/marketplaces/MP35/refunds/RF74',
+      }
+    ],
+    offset    => 0,
+    limit     => 10,
+    next_uri  => undef,
+    total     => 1,
+    uri       => '/v1/marketplaces/MP35/debits/WD2L/refunds?limit=10&offset=0',
+    first_uri => '/v1/marketplaces/MP35/debits/WD2L/refunds?limit=10&offset=0',
+    last_uri  => '/v1/marketplaces/MP35/debits/WD2L/refunds?limit=10&offset=0',
+    previous_uri => undef,
+  }
+
 =head2 void_hold
 
     void_hold($hold)
